abjad-ext-rmakers
=================

Abjad rhythm-maker extension package.

[![Build Status](
    https://travis-ci.org/Abjad/abjad-ext-rmakers.svg?branch=master)](
    https://travis-ci.org/Abjad/abjad-ext-rmakers)
[![Coverage Status](
    https://coveralls.io/repos/github/Abjad/abjad-ext-rmakers/badge.svg?branch=master)](
    https://coveralls.io/github/Abjad/abjad-ext-rmakers?branch=master)
[![Code style: black](
    https://img.shields.io/badge/code%20style-black-000000.svg)](
    https://github.com/ambv/black)
